@@ -50,10 +50,10 @@ ZEND_BEGIN_ARG_INFO_EX(yaf_route_rewrite_match_arginfo, 0, 0, 1)
 ZEND_END_ARG_INFO()
 /* }}} */
 
-static HashTable *yaf_route_rewrite_get_properties(zval *object) /* {{{ */ {
+static HashTable *yaf_route_rewrite_get_properties(yaf_object *object) /* {{{ */ {
 	zval rv;
 	HashTable *ht;
-	yaf_route_rewrite_object *rewrite = Z_YAFROUTEREWRITEOBJ_P(object);
+	yaf_route_rewrite_object *rewrite = (yaf_route_rewrite_object*)(yaf_strip_obj(object));
 
 	if (!rewrite->properties) {
 		ALLOC_HASHTABLE(rewrite->properties);
