@@ -19,6 +19,7 @@
 #endif
 
 #include "php.h"
+#include "Zend/zend_smart_str.h" /* for smart_str */
 
 #include "php_yaf.h"
 #include "yaf_namespace.h"
@@ -29,7 +30,6 @@
 #include "yaf_router.h"
 #include "routes/yaf_route_interface.h"
 #include "routes/yaf_route_static.h"
-#include "zend_smart_str.h" /* for smart_str */
 
 zend_class_entry * yaf_route_static_ce;
 
@@ -43,7 +43,7 @@ ZEND_END_ARG_INFO()
 static inline void yaf_route_strip_uri(const char **req_uri, size_t *req_uri_len) /* {{{ */ {
 	register const char *p = *req_uri;
 	size_t l = *req_uri_len;
-	while (*p == ' ' || *p == YAF_ROUTER_URL_DELIMIETER) {
+	while (*p == YAF_ROUTER_URL_DELIMIETER) {
 		p++; l--;
 	}
 	*req_uri = p;
@@ -51,139 +51,127 @@ static inline void yaf_route_strip_uri(const char **req_uri, size_t *req_uri_len
 }
 /* }}} */
 
-int yaf_route_pathinfo_route(yaf_request_t *request, const char *req_uri, size_t req_uri_len) /* {{{ */ {
-	const char *module = NULL, *controller = NULL, *action = NULL, *rest = NULL;
-	size_t module_len, controller_len, action_len, rest_len;
+void yaf_route_pathinfo_route(yaf_request_object *request, const char *req_uri, size_t req_uri_len) /* {{{ */ {
+	const char *pos;
+	const char *parts[3];
+	uint32_t lens[3];
+	uint32_t current = 0;
+
+	yaf_route_strip_uri(&req_uri, &req_uri_len);
+	if (req_uri_len == 0) {
+		return;
+	}
 
 	do {
-		const char *s;
-
-		yaf_route_strip_uri(&req_uri, &req_uri_len);
-		if (req_uri_len == 0) {
-			break;
+		parts[current] = req_uri;
+		lens[current] = req_uri_len;
+		req_uri_len = 0;
+		if ((pos = memchr(req_uri, YAF_ROUTER_URL_DELIMIETER, lens[current])) != NULL) {
+			req_uri_len = lens[current] - (pos - req_uri + 1);
+			lens[current] = pos - req_uri;
+			req_uri = pos + 1;
+			yaf_route_strip_uri(&req_uri, &req_uri_len);
 		}
+	} while (++current < 3 && req_uri_len);
 
-		if ((s = memchr(req_uri, YAF_ROUTER_URL_DELIMIETER, req_uri_len)) != NULL) {
-			if (yaf_application_is_module_name_str(req_uri, s - req_uri)) {
-				module = req_uri;
-				module_len = s++ - req_uri;
-				req_uri_len -= s - req_uri;
-				req_uri = s;
-
-				yaf_route_strip_uri(&req_uri, &req_uri_len);
-				if (req_uri_len == 0) {
-					break;
-				}
-				if ((s = memchr(req_uri, YAF_ROUTER_URL_DELIMIETER, req_uri_len)) != NULL) {
-					controller = req_uri;
-					controller_len = s++ - req_uri;
-					req_uri_len -= s - req_uri;
-					req_uri = s;
-				} else {
-					controller = req_uri;
-					controller_len = req_uri_len;
-					break;
-				}
+	switch (current) {
+		case 1:
+			if (UNEXPECTED(yaf_is_action_prefer())) {
+				parts[2] = parts[0];
+				parts[0] = NULL;
+				parts[1] = NULL;
+				lens[2] = lens[0];
 			} else {
-				controller = req_uri;
-				controller_len = s++ - req_uri;
-				req_uri_len -= s - req_uri;
-				req_uri = s;
-			}
-		} else {
-			if (yaf_application_is_module_name_str(req_uri, req_uri_len)) {
-				module = req_uri;
-				module_len = req_uri_len;
-			} else {
-				controller = req_uri;
-				controller_len = req_uri_len;
+				parts[1] = parts[0];
+				parts[0] = NULL;
+				parts[2] = NULL;
+				lens[1] = lens[0];
 			}
 			break;
-		}
-
-		yaf_route_strip_uri(&req_uri, &req_uri_len);
-		if (req_uri_len == 0) {
+		case 2:
+			/*if (!yaf_application_is_module_name_str(parts[0], lens[0]) || UNEXPECTED(yaf_is_action_prefer())) { */
+				/* /module/controller/ -> /controller/action */
+				parts[2] = parts[1];
+				parts[1] = parts[0];
+				parts[0] = NULL;
+				lens[2] = lens[1];
+				lens[1] = lens[0];
+			/*}*/
+			break;
+		case 3:
+			if (!yaf_application_is_module_name_str(parts[0], lens[0])) {
+				/* /module/controller/ -> /controller/action */
+				/* action -> call args */
+				req_uri = parts[2];
+				req_uri_len += lens[2] + (req_uri_len? 1 : 0) /* stripped back slash */;
+				parts[2] = parts[1];
+				parts[1] = parts[0];
+				parts[0] = NULL;
+				lens[2] = lens[1];
+				lens[1] = lens[0];
+			}
+			break;
+		default:
 			break;
-		}
-
-		if ((s = memchr(req_uri, YAF_ROUTER_URL_DELIMIETER, req_uri_len)) != NULL) {
-			action = req_uri;
-			action_len = s++ - req_uri;
-			req_uri_len -= s - req_uri;
-			req_uri = s;
-		} else {
-			action = req_uri;
-			action_len = req_uri_len;
-			req_uri_len = 0;
-		}
-
-		yaf_route_strip_uri(&req_uri, &req_uri_len);
-		if (req_uri_len) {
-			rest = req_uri;
-			rest_len = req_uri_len;
-		}
-	} while (0);
-
-	if (controller == NULL) {
-		controller = module;
-		controller_len = module_len;
-		module = NULL;
-	} else if (action == NULL) {
-		if (module && controller) {
-			action = controller;
-			action_len = controller_len;
-			controller = module;
-			controller_len = module_len;
-			module = NULL;
-		} else if (controller && UNEXPECTED(YAF_G(action_prefer))) {
-			action = controller;
-			action_len = controller_len;
-			controller = NULL;
-		}
 	}
 
-	if (module != NULL) {
-		zend_update_property_stringl(yaf_request_ce,
-				request, ZEND_STRL(YAF_REQUEST_PROPERTY_NAME_MODULE), module, module_len);
-	}
-	if (controller != NULL) {
-		zend_update_property_stringl(yaf_request_ce,
-				request, ZEND_STRL(YAF_REQUEST_PROPERTY_NAME_CONTROLLER), controller, controller_len);
-	}
-	if (action != NULL) {
-		zend_update_property_stringl(yaf_request_ce,
-				request, ZEND_STRL(YAF_REQUEST_PROPERTY_NAME_ACTION), action, action_len);
+	if (parts[0]) {
+		if (UNEXPECTED(request->module)) {
+			zend_string_release(request->module);
+		}
+		request->module = yaf_build_camel_name(parts[0], lens[0]);
 	}
 
-	if (rest) {
+	if (parts[1]) {
+		if (UNEXPECTED(request->controller)) {
+			zend_string_release(request->controller);
+		}
+		request->controller = yaf_build_camel_name(parts[1], lens[1]);
+	}
+
+	if (parts[2]) {
+		if (UNEXPECTED(request->action)) {
+			zend_string_release(request->action);
+		}
+		request->action = yaf_build_lower_name(parts[2], lens[2]);
+	}
+
+	if (req_uri_len) {
+		/* call args */
 		zval params;
-		yaf_router_parse_parameters(rest, rest_len, &params);
+		yaf_router_parse_parameters(req_uri, req_uri_len, &params);
 		yaf_request_set_params_multi(request, &params);
 		zval_ptr_dtor(&params);
 	}
-
-	return 1;
 }
 /* }}} */
 
-int yaf_route_static_route(yaf_route_t *route, yaf_request_t *request) /* {{{ */ {
-	zval *uri, *base_uri;
+ZEND_HOT void yaf_route_static_route(yaf_route_t *route, yaf_request_t *req) /* {{{ */ {
 	const char *req_uri;
 	size_t req_uri_len;
+	yaf_request_object *request = Z_YAFREQUESTOBJ_P(req);
 
-	uri = zend_read_property(yaf_request_ce, request, ZEND_STRL(YAF_REQUEST_PROPERTY_NAME_URI), 1, NULL);
-	base_uri = zend_read_property(yaf_request_ce, request, ZEND_STRL(YAF_REQUEST_PROPERTY_NAME_BASE), 1, NULL);
-
-	if (Z_STRLEN_P(base_uri)) {
-		req_uri = yaf_request_strip_base_uri(Z_STR_P(uri), Z_STR_P(base_uri), &req_uri_len);
+	if (request->base_uri) {
+		req_uri = yaf_request_strip_base_uri(request->uri, request->base_uri, &req_uri_len);
 	} else {
-		req_uri = Z_STRVAL_P(uri);
-		req_uri_len = Z_STRLEN_P(uri);
+		req_uri = ZSTR_VAL(request->uri);
+		req_uri_len = ZSTR_LEN(request->uri);
+	}
+	yaf_route_pathinfo_route(request, req_uri, req_uri_len);
+}
+/* }}} */
+
+/** {{{ proto public Yaf_Router_Static::route(Yaf_Request $req)
+*/
+PHP_METHOD(yaf_route_static, route) {
+	yaf_request_t *request;
+
+	if (zend_parse_parameters(ZEND_NUM_ARGS(), "O", &request, yaf_request_ce) == FAILURE) {
+		return;
 	}
 
-	yaf_route_pathinfo_route(request, req_uri, req_uri_len);
-
-	return 1;
+	yaf_route_static_route(getThis(), request);
+	RETURN_TRUE;
 }
 /* }}} */
 
@@ -256,19 +244,6 @@ zend_string * yaf_route_static_assemble(yaf_route_t *this_ptr, zval *info, zval
 }
 /* }}} */
 
-/** {{{ proto public Yaf_Router_Static::route(Yaf_Request $req)
-*/
-PHP_METHOD(yaf_route_static, route) {
-	yaf_request_t *request;
-
-	if (zend_parse_parameters(ZEND_NUM_ARGS(), "O", &request, yaf_request_ce) == FAILURE) {
-		return;
-	} else {
-		RETURN_BOOL(yaf_route_static_route(getThis(), request));
-	}
-}
-/* }}} */
-
 /** {{{ proto public Yaf_Router_Static::match(string $uri)
 */
 PHP_METHOD(yaf_route_static, match) {
@@ -311,6 +286,8 @@ YAF_STARTUP_FUNCTION(route_static) {
 
 	YAF_INIT_CLASS_ENTRY(ce, "Yaf_Route_Static", "Yaf\\Route_Static", yaf_route_static_methods);
 	yaf_route_static_ce = zend_register_internal_class(&ce);
+	yaf_route_static_ce->ce_flags |= ZEND_ACC_FINAL;
+
 	zend_class_implements(yaf_route_static_ce, 1, yaf_route_ce);
 
 	return SUCCESS;
