@@ -25,6 +25,10 @@
 #include "ext/standard/info.h"
 #include "ext/standard/php_string.h"
 
+#ifdef __SSE2__
+#include <emmintrin.h>
+#endif
+
 #include "php_yaf.h"
 #include "yaf_logo.h"
 #include "yaf_loader.h"
@@ -359,19 +363,57 @@ ZEND_HOT int yaf_call_user_method_with_2_arguments(zend_object *obj, zend_functi
 /* }}} */
 
 ZEND_HOT zend_string *yaf_build_camel_name(const char *str, size_t len) /* {{{ */ {
-	unsigned int i;
+	unsigned int ucfirst = 1;
 	zend_string *name = zend_string_alloc(len, 0);
 	unsigned char *p = (unsigned char*)ZSTR_VAL(name);
+	unsigned char *e = p + ZSTR_LEN(name);
+#ifdef __SSE2__
+	while (p + 16 <= e) {
+		uint32_t mask;
+		__m128i rot, lower, upper, delta, line;
+		const __m128i upper_guard = _mm_set1_epi8('A' + 128);
+		const __m128i lower_guard = _mm_set1_epi8('a' + 128);
+		__m128i in = _mm_loadu_si128((__m128i*)str);
 
-	*p++ = toupper(*str);
-	for (i = 1; i < len; i++) {
-		unsigned char ch = str[i];
-		if (ch != '_') {
-			*p++ = tolower(ch);
+		rot = _mm_sub_epi8(in, upper_guard);
+		upper = _mm_cmpgt_epi8(rot, _mm_set1_epi8(-128 + 'Z' - 'A'));
+		delta = _mm_andnot_si128(upper, _mm_set1_epi8('a' - 'A'));
+	    in = _mm_add_epi8(in, delta);
+
+		line = _mm_cmpeq_epi8(in, _mm_set1_epi8('_'));
+		mask = _mm_movemask_epi8(line);
+		delta = _mm_slli_si128(line, 1);
+		if (ucfirst) {
+			delta = _mm_or_si128(delta, _mm_set_epi8(0, 0, 0, 0,
+												     0, 0, 0, 0,
+												     0, 0, 0, 0,
+												     0, 0, 0, 0xff));
+		}
+		ucfirst = mask & (0x1 << 15);
+
+		rot = _mm_sub_epi8(in, lower_guard);
+		lower = _mm_cmpgt_epi8(rot, _mm_set1_epi8(-128 + 'z' - 'a'));;
+		delta = _mm_andnot_si128(lower, delta);
+		delta = _mm_and_si128(delta, _mm_set1_epi8('a' - 'A'));
+		in = _mm_sub_epi8(in, delta);
+
+		_mm_storeu_si128((__m128i*)p, in);
+		p += 16;
+		str += 16;
+	}
+#endif
+	if (p != e) {
+		if (ucfirst) {
+			*p = toupper(*str++);
 		} else {
-			*p++ = ch;
-			i++;
-			*p++ = toupper(str[i]);
+			*p = tolower(*str++);
+		}
+		while (++p != e) {
+			if (*(str - 1) != '_') {
+				*p = tolower(*str++);
+			} else {
+				*p = toupper(*str++);
+			}
 		}
 	}
 	*p = '\0';
@@ -395,10 +437,10 @@ ZEND_HOT zend_string *yaf_build_lower_name(const char *str, size_t len) /* {{{ *
 /* }}} */
 
 ZEND_HOT zend_string *yaf_canonical_name(int type, zend_string *name) /* {{{ */ {
-	const char *p = ZSTR_VAL(name);
-	const char *e = ZSTR_VAL(name) + ZSTR_LEN(name);
-
 	if (type) {
+#if 0
+		const char *p = ZSTR_VAL(name);
+		const char *e = ZSTR_VAL(name) + ZSTR_LEN(name);
 		/* Module, Controller */
 		if ((*p < 'A' || *p > 'Z') && *p != '_') {
 			goto sanitize;
@@ -410,6 +452,7 @@ ZEND_HOT zend_string *yaf_canonical_name(int type, zend_string *name) /* {{{ */
 		}
 		return zend_string_copy(name);
 sanitize:
+#endif
 		return yaf_build_camel_name(ZSTR_VAL(name), ZSTR_LEN(name));
 	} else {
 		return zend_string_tolower(name);
@@ -417,6 +460,34 @@ sanitize:
 }
 /* }}} */
 
+ZEND_HOT void yaf_replace_chr(char *name, uint32_t len, zend_uchar f, zend_uchar t) /* {{{ */ {
+	char *pos = name;
+#ifdef __SSE2__
+	do {
+		const __m128i from = _mm_set1_epi8(f);
+		const __m128i delta = _mm_set1_epi8(t - f);
+		while (len >= 16) {
+			__m128i op = _mm_loadu_si128((__m128i *)pos);
+			__m128i eq = _mm_cmpeq_epi8(op, from);
+			if (_mm_movemask_epi8(eq)) {
+				eq = _mm_and_si128(eq, delta);
+				op = _mm_add_epi8(op, eq);
+				_mm_storeu_si128((__m128i*)pos, op);
+			}
+			len -= 16;
+			pos += 16;
+		}
+	} while (0);
+#endif
+	if (len) {
+		name = pos; /* reset start */
+		while ((pos = memchr(pos, f, len - (pos - name)))) {
+			*pos++ = t;
+		}
+	}
+}
+/* }}} */
+
 /** {{{ PHP_GINIT_FUNCTION
 */
 PHP_GINIT_FUNCTION(yaf)
