@@ -54,13 +54,14 @@ static zend_always_inline yaf_dispatcher_object *php_yaf_dispatcher_fetch_object
 	return (yaf_dispatcher_object *)((char*)(obj) - XtOffsetOf(yaf_dispatcher_object, std));
 }
 
-#define YAF_PLUGIN_HANDLE(dispatcher, plugins, ev) \
+#define YAF_PLUGIN_HANDLE(dispatcher, ev) \
 	do { \
-		if (plugins) { \
+		if ((dispatcher)->plugins) { \
 			zval _r, *_t;\
 			zend_function *_f; \
 			yaf_dispatcher_object *_d = (dispatcher); \
-			ZEND_HASH_FOREACH_VAL(plugins, _t) { \
+			HashTable *_pls = _d->plugins; \
+			ZEND_HASH_FOREACH_VAL(_pls, _t) { \
 				_f = zend_hash_str_find_ptr(&(Z_OBJCE_P(_t)->function_table), (ev), sizeof(ev) - 1); \
 				ZEND_ASSERT(_f); \
 				if (_f->type == ZEND_USER_FUNCTION) {\
