@@ -76,7 +76,7 @@ ZEND_BEGIN_ARG_INFO_EX(yaf_request_set_param_arginfo, 0, 0, 1)
 	ZEND_ARG_INFO(0, value)
 ZEND_END_ARG_INFO()
 
-ZEND_BEGIN_ARG_INFO_EX(yaf_request_get_arginfo, 0, 0, 1)
+ZEND_BEGIN_ARG_INFO_EX(yaf_request_get_arginfo, 0, 0, 0)
 	ZEND_ARG_INFO(0, name)
 	ZEND_ARG_INFO(0, default)
 ZEND_END_ARG_INFO()
@@ -144,9 +144,9 @@ static void yaf_request_object_free(zend_object *object) /* {{{ */ {
 }
 /* }}} */
 
-static HashTable *yaf_request_get_gc(zval *object, zval **table, int *n) /* {{{ */
+static HashTable *yaf_request_get_gc(yaf_object *object, zval **table, int *n) /* {{{ */
 {
-	yaf_request_object *request = Z_YAFREQUESTOBJ_P(object);
+	yaf_request_object *request = php_yaf_request_fetch_object(yaf_strip_obj(object));
 
 	*table = NULL;
 	*n = 0;
@@ -155,10 +155,10 @@ static HashTable *yaf_request_get_gc(zval *object, zval **table, int *n) /* {{{
 }
 /* }}} */
 
-static HashTable *yaf_request_get_properties(zval *object) /* {{{ */ {
+static HashTable *yaf_request_get_properties(yaf_object *object) /* {{{ */ {
 	zval rv;
 	HashTable *ht;
-	yaf_request_object *request = Z_YAFREQUESTOBJ_P(object);
+	yaf_request_object *request = php_yaf_request_fetch_object(yaf_strip_obj(object));
 
 	if (!request->properties) {
 		ALLOC_HASHTABLE(request->properties);
@@ -327,22 +327,28 @@ zend_string *yaf_request_get_language(yaf_request_object *request) /* {{{ */ {
 }
 /* }}} */
 
-static zval* yaf_request_read_property(zval *zobj, zval *name, int type, void **cache_slot, zval *rv) /* {{{ */ {
+static zval* yaf_request_read_property(yaf_object *obj, void/*for php8 portability*/ *name, int type, void **cache_slot, zval *rv) /* {{{ */ {
 	zend_string *member;
-	yaf_request_object *request = Z_YAFREQUESTOBJ_P(zobj);
+	yaf_request_object *request = php_yaf_request_fetch_object(yaf_strip_obj(obj));
 
-	if (UNEXPECTED(Z_TYPE_P(name) != IS_STRING)) {
+#if PHP_VERSION_ID < 80000
+	if (UNEXPECTED(Z_TYPE_P((zval*)name) != IS_STRING)) {
 		return &EG(uninitialized_zval);
 	}
+#endif
+
+#if PHP_VERSION_ID < 80000
+	member = Z_STR_P((zval*)name);
+#else
+	member = (zend_string*)name;
+#endif
 
 	if (UNEXPECTED(type == BP_VAR_W || type == BP_VAR_RW)) {
 		php_error_docref(NULL, E_WARNING,
-				"Indirect modification of Yaf_Reqeust internal property '%s' is not allowed", Z_STRVAL_P(name));
+				"Indirect modification of Yaf_Reqeust internal property '%s' is not allowed", ZSTR_VAL(member));
 		return &EG(error_zval);
 	}
 
-	member = Z_STR_P(name);
-
 	switch (ZSTR_LEN(member)) {
 		case 3:
 			if (yaf_slip_equal(ZSTR_VAL(member), ZEND_STRS("uri"))) {
@@ -418,8 +424,7 @@ static zval* yaf_request_read_property(zval *zobj, zval *name, int type, void **
 			default:
 			break;
 	}
-
-	return std_object_handlers.read_property(zobj, name, type, cache_slot, rv);
+	return std_object_handlers.read_property(obj, name, type, cache_slot, rv);
 }
 /* }}} */
 
@@ -553,15 +558,19 @@ int yaf_request_set_base_uri(yaf_request_object *request, zend_string *base_uri,
 }
 /* }}} */
 
-static YAF_WRITE_HANDLER yaf_request_write_property(zval *zobj, zval *name, zval *value, void **cache_slot) /* {{{ */ {
+static YAF_WRITE_HANDLER yaf_request_write_property(yaf_object *obj, void *name, zval *value, void **cache_slot) /* {{{ */ {
 	zend_string *member;
-	yaf_request_object *request = Z_YAFREQUESTOBJ_P(zobj);
+	yaf_request_object *request = php_yaf_request_fetch_object(yaf_strip_obj(obj));
 
-	if (UNEXPECTED(Z_TYPE_P(name) != IS_STRING)) {
+#if PHP_VERSION_ID < 80000
+	if (UNEXPECTED(Z_TYPE_P((zval*)name) != IS_STRING)) {
 		YAF_WHANDLER_RET(value);
 	}
 
-	member = Z_STR_P(name);
+	member = Z_STR_P((zval*)name);
+#else
+	member = (zend_string*)name;
+#endif
 
 	if (zend_string_equals_literal(member, "method")) {
 		if (UNEXPECTED(Z_TYPE_P(value) != IS_STRING || Z_STRLEN_P(value) == 0)) {
@@ -602,12 +611,13 @@ static YAF_WRITE_HANDLER yaf_request_write_property(zval *zobj, zval *name, zval
 		zend_string_equals_literal(member, "language") ||
 		zend_string_equals_literal(member, "routed") ||
 		zend_string_equals_literal(member, "params")) {
+
 		php_error_docref(NULL, E_WARNING,
-				"Modification of Yaf_Request internal property '%s' is not allowed", Z_STRVAL_P(name));
+				"Modification of Yaf_Request internal property '%s' is not allowed", ZSTR_VAL(member));
 		YAF_WHANDLER_RET(value);
 	}
 
-	return std_object_handlers.write_property(zobj, name, value, cache_slot);
+    return std_object_handlers.write_property(obj, name, value, cache_slot);
 }
 /* }}} */
 
@@ -1368,7 +1378,7 @@ zend_function_entry yaf_request_methods[] = {
 	PHP_ME(yaf_request, getRequest, yaf_request_get_arginfo, ZEND_ACC_PUBLIC)
 	PHP_ME(yaf_request, getPost, yaf_request_get_arginfo, ZEND_ACC_PUBLIC)
 	PHP_ME(yaf_request, getCookie, yaf_request_get_arginfo, ZEND_ACC_PUBLIC)
-	PHP_ME(yaf_request, getRaw, yaf_request_get_arginfo, ZEND_ACC_PUBLIC)
+	PHP_ME(yaf_request, getRaw, yaf_request_void_arginfo, ZEND_ACC_PUBLIC)
 	PHP_ME(yaf_request, getFiles, yaf_request_get_arginfo, ZEND_ACC_PUBLIC)
 	PHP_ME(yaf_request, get, yaf_request_get_arginfo, ZEND_ACC_PUBLIC)
 	PHP_ME(yaf_request, getServer, yaf_request_get_arginfo, ZEND_ACC_PUBLIC)
@@ -1415,8 +1425,8 @@ YAF_STARTUP_FUNCTION(request){
 	yaf_request_obj_handlers.offset = XtOffsetOf(yaf_request_object, std);
 	yaf_request_obj_handlers.free_obj = yaf_request_object_free;
 	yaf_request_obj_handlers.get_properties = yaf_request_get_properties;;
-	yaf_request_obj_handlers.read_property = yaf_request_read_property;
-	yaf_request_obj_handlers.write_property = yaf_request_write_property;
+	yaf_request_obj_handlers.read_property = (zend_object_read_property_t)yaf_request_read_property;
+	yaf_request_obj_handlers.write_property = (zend_object_write_property_t)yaf_request_write_property;
 	yaf_request_obj_handlers.get_gc = yaf_request_get_gc;
 	yaf_request_obj_handlers.clone_obj = NULL;
 
