@@ -48,6 +48,19 @@ ZEND_END_ARG_INFO()
 ZEND_BEGIN_ARG_INFO_EX(yaf_router_name_arginfo, 0, 0, 1)
 	ZEND_ARG_INFO(0, name)
 ZEND_END_ARG_INFO()
+
+ZEND_BEGIN_ARG_INFO_EX(yaf_router_route_arginfo, 0, 0, 1)
+	ZEND_ARG_INFO(0, request)
+ZEND_END_ARG_INFO()
+
+ZEND_BEGIN_ARG_INFO_EX(yaf_router_add_route_arginfo, 0, 0, 2)
+	ZEND_ARG_INFO(0, name)
+	ZEND_ARG_INFO(0, route)
+ZEND_END_ARG_INFO()
+
+ZEND_BEGIN_ARG_INFO_EX(yaf_router_add_config_arginfo, 0, 0, 1)
+	ZEND_ARG_INFO(0, config)
+ZEND_END_ARG_INFO()
 /* }}} */
 
 static zend_object *yaf_router_new(zend_class_entry *ce) /* {{{ */ {
@@ -78,10 +91,10 @@ static void yaf_router_object_free(zend_object *object) /* {{{ */ {
 }
 /* }}} */
 
-static HashTable *yaf_router_get_properties(zval *object) /* {{{ */ {
+static HashTable *yaf_router_get_properties(yaf_object *obj) /* {{{ */ {
 	zval rv;
 	HashTable *ht;
-	yaf_router_object *router = Z_YAFROUTEROBJ_P(object);
+	yaf_router_object *router = php_yaf_router_fetch_object(yaf_strip_obj(obj));
 
 	if (!router->properties) {
 		ALLOC_HASHTABLE(router->properties);
@@ -156,7 +169,11 @@ ZEND_HOT int yaf_router_route(yaf_router_object *router, yaf_request_t *request)
 			}
 		} else {
 			zval ret;
+#if PHP_VERSION_ID < 80000
 			zend_call_method_with_1_params(route, Z_OBJCE_P(route), NULL, "route", &ret, request);
+#else
+            zend_call_method_with_1_params(Z_OBJ_P(route), Z_OBJCE_P(route), NULL, "route", &ret, request);
+#endif
 			if (Z_TYPE(ret) != IS_TRUE && (Z_TYPE(ret) != IS_LONG || !Z_LVAL(ret))) {
 				zval_ptr_dtor(&ret);
 				continue;
@@ -390,9 +407,9 @@ PHP_METHOD(yaf_router, getCurrentRoute) {
  */
 zend_function_entry yaf_router_methods[] = {
 	PHP_ME(yaf_router, __construct,	yaf_router_void_arginfo, ZEND_ACC_PUBLIC | ZEND_ACC_CTOR)
-	PHP_ME(yaf_router, addRoute,  	NULL, ZEND_ACC_PUBLIC)
-	PHP_ME(yaf_router, addConfig, 	NULL, ZEND_ACC_PUBLIC)
-	PHP_ME(yaf_router, route,		NULL, ZEND_ACC_PUBLIC)
+	PHP_ME(yaf_router, addRoute,  	yaf_router_add_route_arginfo, ZEND_ACC_PUBLIC)
+	PHP_ME(yaf_router, addConfig, 	yaf_router_add_config_arginfo, ZEND_ACC_PUBLIC)
+	PHP_ME(yaf_router, route,		yaf_router_route_arginfo, ZEND_ACC_PUBLIC)
 	PHP_ME(yaf_router, getRoute,  	yaf_router_name_arginfo, ZEND_ACC_PUBLIC)
 	PHP_ME(yaf_router, getRoutes,   yaf_router_void_arginfo, ZEND_ACC_PUBLIC)
 	PHP_ME(yaf_router, getCurrentRoute,	yaf_router_void_arginfo, ZEND_ACC_PUBLIC)
